-- Licensed Materials - Property of IBM
-- 5725-A20
-- Copyright IBM Corporation 2015, 2016.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create schema (tables) for DB2 UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg DB2ADMIN
--    
-- @TAB_TS@ - tablespace for data, e.g. PFSDATA
-- @IDX_TS@ - tablespace for indexes, e.g. PFSIDX
-- @LOB_TS@ - tablespace for binary objects, e.g. PFSLOB
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of GRANT statements 
--    by replacing the string "--GRANT STMT--" with ""
-- 
-- @DB_USER@ = database user for the pfs schema, only needed for GRANT statements
--    for database installation with enhanced security
--
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf createTable_PFS.sql
--
-- ------------------------------------------------------------------------------------

------------- tables
CREATE TABLE @SCHEMA@.PFS_SAVED_SEARCHES
(
  SEARCH_ID                          BIGINT                            NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 2, INCREMENT BY 1),
  SEARCH_NAME                        VARCHAR(256)                      NOT NULL ,
  ORGANIZATION                       VARCHAR(32)                       NOT NULL ,
  SHARED                             SMALLINT                          NOT NULL ,
  OWNER                              VARCHAR(128)                      NOT NULL ,
  QUERY                              CLOB(1048576)                              ,
  LAST_UPDATED                       TIMESTAMP                         NOT NULL ,
  LAST_UPDATED_BY                    VARCHAR(128)                      NOT NULL ,
  SHARED_UNIQUE					     BIGINT  									GENERATED ALWAYS AS (CASE WHEN SHARED=1 THEN 1 ELSE SEARCH_ID END),
  PRIMARY KEY ( SEARCH_ID )
) IN @TAB_TS@ INDEX IN @IDX_TS@ LONG IN @LOB_TS@;

-- Enforce rule that all shared searches must have a unique name
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX1 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, SHARED_UNIQUE);

-- Enforce rule that all searches must have a unique name for the creator
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX2 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, OWNER);

CREATE INDEX @SCHEMA@.SAVED_SEARCH_IDX3 ON @SCHEMA@.PFS_SAVED_SEARCHES (OWNER, SHARED);

--GRANT STMT--GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PFS_SAVED_SEARCHES TO USER @DB_USER@;

