-- Licensed Materials - Property of IBM
-- 5725-A20
-- Copyright IBM Corporation 2015, 2016.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or 
-- disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- --------------------------------------------------------------------
--
-- Scriptfile to  and schema (tables) for 
-- DB2 z/OS
--
-----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg PFSDB
-- @SCHEMA@ = the schema name, eg PFSDB
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of 
--    GRANT statements --    by replacing the string 
--    "--GRANT STMT--" with ""
-- 
-- @DB_USER@ = database user for the pfs schema, only needed for 
--    GRANT statements for database installation with enhanced security
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--           deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf createTable_PFS.sql
--
-- --------------------------------------------------------------------

-------------------
-- Create tables --
-------------------
CREATE TABLE @SCHEMA@.PFS_SAVED_SEARCHES
(
  SEARCH_ID BIGINT NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 100, INCREMENT BY 1),
  SEARCH_NAME VARCHAR(256) NOT NULL,
  ORGANIZATION VARCHAR(32) NOT NULL,
  SHARED SMALLINT NOT NULL,
  OWNER VARCHAR(128) NOT NULL,
  QUERY CLOB(1048576),
  LAST_UPDATED TIMESTAMP NOT NULL,
  LAST_UPDATED_BY VARCHAR(128) NOT NULL,
  SHARED_UNIQUE BIGINT,
  PRIMARY KEY ( SEARCH_ID )
) IN @DB_NAME@.TSPFS001;

CREATE UNIQUE INDEX @SCHEMA@.PFS_SAVED_SEARCH_P 
  ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_ID) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- Enforce rule that all shared searches must have a unique name
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX1 
  ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, SHARED_UNIQUE)
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- Enforce rule that all searches must have a unique name for the creator
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX2 
  ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, OWNER)
  NOT PADDED
  USING STOGROUP @STOGRP@;  

CREATE INDEX @SCHEMA@.SAVED_SEARCH_IDX3
  ON @SCHEMA@.PFS_SAVED_SEARCHES (OWNER, SHARED)
  NOT PADDED
  USING STOGROUP @STOGRP@;  
  
-- auxiliary table for LOB column QUERY
CREATE AUX TABLE @SCHEMA@.ATLOB01
   IN @DB_NAME@.PFSLOB01
   STORES @SCHEMA@.PFS_SAVED_SEARCHES COLUMN QUERY;
-- auxiliary index for LOB column QUERY
CREATE UNIQUE INDEX @SCHEMA@.ATLOB01I
  ON @SCHEMA@.ATLOB01 
  USING STOGROUP @STOGRP@;
  
CREATE TRIGGER @SCHEMA@.PFS_SAVED_SRCH_INSERT
  AFTER INSERT ON @SCHEMA@.PFS_SAVED_SEARCHES
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.PFS_SAVED_SEARCHES 
  SET SHARED_UNIQUE = (CASE WHEN SHARED=1 THEN 1 ELSE SEARCH_ID END);

CREATE TRIGGER @SCHEMA@.PFS_SAVED_SRCH_UPDATE
  AFTER UPDATE OF SHARED ON @SCHEMA@.PFS_SAVED_SEARCHES
  REFERENCING NEW AS NEW
  FOR EACH ROW MODE DB2SQL
  UPDATE @SCHEMA@.PFS_SAVED_SEARCHES 
  SET SHARED_UNIQUE = (CASE WHEN SHARED=1 THEN 1 ELSE SEARCH_ID END);


--GRANT STMT--GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PFS_SAVED_SEARCHES TO @DB_USER@;
