-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014, 2015. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg BPMDB
-- @SCHEMA@ = the schema name, eg BPMUSER
-- @BPTABLE32K@ = buffer pool name
-- @BPTABLE4K@ = buffer pool name

-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf create_bpd_change_log.ddl
--
-- ------------------------------------------------------------------------------------


-- for @SCHEMA@.PFS_BPD_CHANGE_LOG table:
CREATE TABLESPACE FDBPDTS0 IN @DB_NAME@
	USING STOGROUP @STOGRP@
	SEGSIZE 32
	LOCKMAX SYSTEM
	LOCKSIZE ROW
	DEFINE YES
	CCSID UNICODE
	BUFFERPOOL @BPTABLE4K@    
;

-- for @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER table:
CREATE TABLESPACE FDBPDTS1 IN @DB_NAME@
	USING STOGROUP @STOGRP@
	SEGSIZE 32
	LOCKMAX SYSTEM
	LOCKSIZE ROW
	DEFINE YES
	CCSID UNICODE
	BUFFERPOOL @BPTABLE4K@    
;

-- for @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER_LOG table:
CREATE TABLESPACE FDBPDTS2 IN @DB_NAME@
	USING STOGROUP @STOGRP@
	SEGSIZE 32
	LOCKMAX SYSTEM
	LOCKSIZE ROW
	DEFINE YES
	CCSID UNICODE
	BUFFERPOOL @BPTABLE4K@    
;

-- for @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL table:
CREATE TABLESPACE FDBPDTS3 IN @DB_NAME@
	USING STOGROUP @STOGRP@
	SEGSIZE 32
	LOCKMAX SYSTEM
	LOCKSIZE ROW
	DEFINE YES
	CCSID UNICODE
	BUFFERPOOL @BPTABLE4K@    
;

-- ------------------
-- PFS_BPD_CHANGE_LOG
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG (
	ID                   BIGINT          NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 1, INCREMENT BY 1),
	TASK_ID              DECIMAL(12,0),
	INSTANCE_ID          DECIMAL(12,0),
	TYPE                 SMALLINT        NOT NULL,
	PARTITION            SMALLINT        NOT NULL,
	ENTRY_TIME           TIMESTAMP       NOT NULL,
	CONSUMER_001         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_002         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_003         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_004         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_005         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_006         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_007         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_008         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_009         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_010         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_011         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_012         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_013         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_014         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_015         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_016         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_017         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_018         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_019         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_020         SMALLINT        NOT NULL DEFAULT 0,
	PRIMARY KEY (ID)
) IN @DB_NAME@.FDBPDTS0;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCL_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG (ID) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (TASK_ID, INSTANCE_ID, TYPE DESC, ENTRY_TIME DESC) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_001) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_001, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_002) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_002, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_003) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_003, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_004) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_004, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_005) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_005, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

-- Create these the following indexes if additional consumers of the BPD change log are configured.

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_006) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_006, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_007) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_007, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_008) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_008, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_009) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_009, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_010) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_010, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_011) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_011, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_012) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_012, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_013) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_013, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_014) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_014, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_015) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_015, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_016) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_016, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_017) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_017, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_018) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_018, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_019) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_019, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_020) USING STOGROUP @STOGRP@;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_020, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) USING STOGROUP @STOGRP@;

-- ---------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          VARCHAR(128)   NOT NULL,
	CONSUMER_ID          VARCHAR(384),
	PRIMARY KEY (COLUMN_NAME)
) IN @DB_NAME@.FDBPDTS1;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLC_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER (COLUMN_NAME) USING STOGROUP @STOGRP@;

-- -------------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (
    SOURCE_ID            VARCHAR(128)   NOT NULL,
	CONSUMER_ID          VARCHAR(384)   NOT NULL,
	START_TIME           TIMESTAMP      NOT NULL,
	END_TIME             TIMESTAMP,
	PROCESSED_TASKS      BIGINT,
	PROCESSED_INSTANCES  BIGINT,
	FAILED_TASKS         BIGINT,
	FAILED_INSTANCES     BIGINT,
	MESSAGE              VARCHAR(4000),
	PRIMARY KEY (SOURCE_ID, CONSUMER_ID, START_TIME)
)  IN @DB_NAME@.FDBPDTS2;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLCL_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (SOURCE_ID, CONSUMER_ID, START_TIME) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (SOURCE_ID, CONSUMER_ID, START_TIME, END_TIME, PROCESSED_TASKS) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, START_TIME) USING STOGROUP @STOGRP@;

-- ------------------
-- PFS_BPD_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL (
  	OPERATION            VARCHAR(128)    NOT NULL, 
	START_TIME           TIMESTAMP,
	COMPLETION_TIME      TIMESTAMP
)  IN @DB_NAME@.FDBPDTS3;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL (OPERATION) USING STOGROUP @STOGRP@;


-- for @SCHEMA@.PFS_PARTITIONING_CONTROLLER table:
CREATE TABLESPACE PFSPTTS5 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;

-- for @SCHEMA@.PFS_PARTITIONING_AGENT table:
CREATE TABLESPACE PFSPTTS6 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@ 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;

-- for @SCHEMA@.PFS_PARTITIONING_AUDIT table:
CREATE TABLESPACE PFSPTTS7 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@ 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;

-------------------
-- Create tables --
-------------------

CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID VARCHAR(512) NOT NULL, 
  UNIQUE_ID DECIMAL(19) NOT NULL, 
  EXPIRY TIMESTAMP NOT NULL, 
  TARGET VARCHAR(1024) NOT NULL, 
  STATE VARCHAR(1024) NOT NULL,
  PRIMARY KEY (CONTROLLER_GROUP_ID)
) IN @DB_NAME@.PFSPTTS5;

CREATE UNIQUE INDEX
@SCHEMA@.FD_BPD_IDX_CTRL_PK ON 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER
(CONTROLLER_GROUP_ID) 
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX
@SCHEMA@.PFS_PTN_CNTRLR_UK ON 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER
(UNIQUE_ID) 
USING STOGROUP @STOGRP@;

CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_AGENT
(
  CONTROLLER_GROUP_ID VARCHAR(512) NOT NULL, 
  UNIQUE_ID DECIMAL(19) NOT NULL, 
  EXPIRY TIMESTAMP NOT NULL, 
  TARGET VARCHAR(1024) NOT NULL, 
  WEIGHT SMALLINT NOT NULL,
  REQUEST VARCHAR(1024) NOT NULL,
  REQUEST_SEQ DECIMAL(19) NOT NULL, 
  RANGE_FIRST DECIMAL(19), 
  RANGE_LAST DECIMAL(19), 
  ACK_SEQ DECIMAL(19) NOT NULL, 
  PRIMARY KEY (CONTROLLER_GROUP_ID, UNIQUE_ID)
) IN @DB_NAME@.PFSPTTS6;

CREATE UNIQUE INDEX
@SCHEMA@.PFS_PTN_AGT_PK ON 
@SCHEMA@.PFS_PARTITIONING_AGENT
(CONTROLLER_GROUP_ID, UNIQUE_ID) 
USING STOGROUP @STOGRP@;

CREATE INDEX 
@SCHEMA@.PFS_PARTITIONING_AGENT_IDX on 
@SCHEMA@.PFS_PARTITIONING_AGENT 
(CONTROLLER_GROUP_ID, EXPIRY, REQUEST) 
USING STOGROUP @STOGRP@;

CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_AUDIT
(
  ID DECIMAL(19) NOT NULL GENERATED 
     ALWAYS AS IDENTITY,
  CONTROLLER_GROUP_ID VARCHAR(512) NOT NULL,
  ENTRY_TIME TIMESTAMP NOT NULL,
  TARGET VARCHAR(512) NOT NULL,
  MESSAGE VARCHAR(4000)           ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.PFSPTTS7;

CREATE UNIQUE INDEX 
 @SCHEMA@.PTN_AUDIT_PK ON 
 @SCHEMA@.PFS_PARTITIONING_AUDIT 
 (ID) 
 USING STOGROUP @STOGRP@;

CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_SEQ
     START WITH 1
     INCREMENT BY 1
     NO MAXVALUE
     NO CYCLE
     CACHE 24;

-- Initial data for the PFS_BPD_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020');

COMMIT;
     