-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg BPMDB
-- @SCHEMA@ = the schema name, eg BPMUSER, the same as BPE table
-- @BPTABLE4K@ = buffer pool name
-- @BPTABLE32K@ = buffer pool name

-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf create_bpel_change_log.ddl
--
-- ------------------------------------------------------------------------------------


-- for @SCHEMA@.PFS_BPEL_CHANGE_LOG table:
CREATE TABLESPACE PFSCLTS1
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPTABLE4K@
  SEGSIZE 32
  COMPRESS YES
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE NO
  CCSID UNICODE;

-- for @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER table:
CREATE TABLESPACE PFSCLTS2
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPTABLE4K@
  SEGSIZE 32
  COMPRESS YES
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE NO
  CCSID UNICODE;

-- for @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER_LOG table:
CREATE TABLESPACE PFSCLTS3
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPTABLE4K@
  SEGSIZE 32
  COMPRESS YES
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE NO
  CCSID UNICODE;
  
-- for @SCHEMA@.PFS_BPEL_CHANGE_LOG_UTIL table:
CREATE TABLESPACE PFSCLTS4
  IN @DB_NAME@
  USING STOGROUP @STOGRP@
  BUFFERPOOL @BPTABLE4K@
  SEGSIZE 32
  COMPRESS YES
  LOCKMAX SYSTEM
  LOCKSIZE ROW
  DEFINE NO
  CCSID UNICODE;

-- for @SCHEMA@.PFS_PARTITIONING_CONTROLLER table:
CREATE TABLESPACE PFSPTTS5 
   IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;

-- for @SCHEMA@.PFS_PARTITIONING_AGENT table:
CREATE TABLESPACE PFSPTTS6 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@ 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;

-- for @SCHEMA@.PFS_PARTITIONING_AUDIT table:
CREATE TABLESPACE PFSPTTS7 IN @DB_NAME@ 
   USING STOGROUP @STOGRP@ 
   BUFFERPOOL @BPTABLE32K@ 
   SEGSIZE 32
   DEFINE NO
   LOCKSIZE ROW
   LOCKMAX 0
   CCSID UNICODE;
   
-- ------------------
-- PFS_BPEL_CHANGE_LOG
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
 PKID CHAR(16) FOR BIT DATA NOT NULL ,
 OBJECT_TYPE INTEGER NOT NULL ,
 OBJECT_ID CHAR(16) FOR BIT DATA NOT NULL ,
 EVENT INTEGER NOT NULL ,
 EVENT_TIME TIMESTAMP NOT NULL ,
 EVENT_KIND INTEGER NOT NULL ,
 PARTITION INTEGER ,
 VERSION_ID SMALLINT NOT NULL ,
 CONSUMER_001         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_002         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_003         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_004         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_005         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_006         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_007         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_008         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_009         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_010         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_011         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_012         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_013         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_014         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_015         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_016         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_017         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_018         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_019         SMALLINT        NOT NULL DEFAULT 0,
 CONSUMER_020         SMALLINT        NOT NULL DEFAULT 0,
  PRIMARY KEY (PKID)
) IN @DB_NAME@.PFSCLTS1;

CREATE UNIQUE INDEX
  @SCHEMA@.INDEXER_LOG_P
  ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  PKID
)
USING STOGROUP @STOGRP@;

CREATE INDEX
  @SCHEMA@.IL_OID
  ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  OBJECT_ID
)
USING STOGROUP @STOGRP@;

CREATE INDEX
  @SCHEMA@.IL_KND
  ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  EVENT_KIND
)
USING STOGROUP @STOGRP@;

CREATE INDEX
  @SCHEMA@.IL_PARTTN
  ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  PARTITION
)
USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.BPCCL_IDX1 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_001, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX2 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_002, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX3 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_003, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX4 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_004, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX5 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_005, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX6 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_006, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX7 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_007, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX8 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_008, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX9 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_009, PARTITION) USING STOGROUP @STOGRP@;
CREATE INDEX @SCHEMA@.BPCCL_IDX10 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_010, PARTITION) USING STOGROUP @STOGRP@;

-- View: IndexerLog
CREATE VIEW @SCHEMA@.PFS_BPEL_CHANGE_LOG_V(PKID, OBJECT_TYPE, OBJECT_ID, EVENT,
 EVENT_TIME, KIND, PARTITION ) AS
 SELECT @SCHEMA@.PFS_BPEL_CHANGE_LOG.PKID,
 @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_TYPE, @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_ID,
 @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT, @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_TIME,
 @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_KIND, @SCHEMA@.PFS_BPEL_CHANGE_LOG.PARTITION
 FROM @SCHEMA@.PFS_BPEL_CHANGE_LOG;
 
-- ---------------------------
-- PFS_BPEL_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          VARCHAR(128)   NOT NULL,
	CONSUMER_ID          VARCHAR(256),
	PRIMARY KEY (COLUMN_NAME)
) IN @DB_NAME@.PFSCLTS2;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLC_PK ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER (COLUMN_NAME) USING STOGROUP @STOGRP@;

-- -------------------------------
-- PFS_BPEL_CHANGE_LOG_CONSUMER_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (
	SOURCE_ID            VARCHAR(128)   NOT NULL,
	CONSUMER_ID          VARCHAR(256)   NOT NULL,
	START_TIME           TIMESTAMP      NOT NULL,
	END_TIME             TIMESTAMP,
	PROCESSED_TASKS      BIGINT,
	PROCESSED_INSTANCES  BIGINT,
	FAILED_TASKS         BIGINT,
	FAILED_INSTANCES     BIGINT,
	MESSAGE              VARCHAR(4000),
	PRIMARY KEY (SOURCE_ID, CONSUMER_ID, START_TIME)
)  IN @DB_NAME@.PFSCLTS3;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLCL_PK ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (SOURCE_ID, CONSUMER_ID, START_TIME) USING STOGROUP @STOGRP@;

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, END_TIME) USING STOGROUP @STOGRP@;

-- ------------------
-- PFS_BPEL_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_UTIL (
  	OPERATION            VARCHAR(128)    NOT NULL, 
	START_TIME           TIMESTAMP,
	COMPLETION_TIME      TIMESTAMP
)  IN @DB_NAME@.FDBPELTS4;


-- ------------------
-- PFS_PARTITIONING_CONTROLLER
-- ------------------
CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID VARCHAR(256) NOT NULL, 
  UNIQUE_ID DECIMAL(19) NOT NULL, 
  EXPIRY TIMESTAMP NOT NULL, 
  TARGET VARCHAR(1024) NOT NULL, 
  STATE VARCHAR(1024) NOT NULL,
  PRIMARY KEY (CONTROLLER_GROUP_ID)
) IN @DB_NAME@.PFSPTTS5;

CREATE UNIQUE INDEX
@SCHEMA@.FD_BPEL_IDX_CTRL_PK ON 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER
(CONTROLLER_GROUP_ID) 
USING STOGROUP @STOGRP@;

CREATE UNIQUE INDEX
@SCHEMA@.PFS_PTN_CNTRLR_UK ON 
@SCHEMA@.PFS_PARTITIONING_CONTROLLER
(UNIQUE_ID) 
USING STOGROUP @STOGRP@;

-- ------------------
-- PFS_PARTITIONING_AGENT
-- ------------------
CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_AGENT
(
  CONTROLLER_GROUP_ID VARCHAR(256) NOT NULL, 
  UNIQUE_ID DECIMAL(19) NOT NULL, 
  EXPIRY TIMESTAMP NOT NULL, 
  TARGET VARCHAR(512) NOT NULL, 
  WEIGHT SMALLINT NOT NULL,
  REQUEST VARCHAR(1024) NOT NULL,
  REQUEST_SEQ DECIMAL(19) NOT NULL, 
  RANGE_FIRST DECIMAL(19), 
  RANGE_LAST DECIMAL(19), 
  ACK_SEQ DECIMAL(19) NOT NULL, 
  PRIMARY KEY (CONTROLLER_GROUP_ID, UNIQUE_ID)
) IN @DB_NAME@.PFSPTTS6;

CREATE UNIQUE INDEX
@SCHEMA@.PFS_PTN_AGT_PK ON 
@SCHEMA@.PFS_PARTITIONING_AGENT
(CONTROLLER_GROUP_ID, UNIQUE_ID) 
USING STOGROUP @STOGRP@;

CREATE INDEX 
@SCHEMA@.PFS_PARTITIONING_AGENT_IDX on 
@SCHEMA@.PFS_PARTITIONING_AGENT 
(CONTROLLER_GROUP_ID, EXPIRY, REQUEST) 
USING STOGROUP @STOGRP@;

-- ------------------
-- PFS_PARTITIONING_AUDIT
-- ------------------
CREATE TABLE 
@SCHEMA@.PFS_PARTITIONING_AUDIT
(
  ID DECIMAL(19) NOT NULL GENERATED 
     ALWAYS AS IDENTITY,
  CONTROLLER_GROUP_ID VARCHAR(256) NOT NULL,
  ENTRY_TIME TIMESTAMP NOT NULL,
  TARGET VARCHAR(512) NOT NULL,
  MESSAGE VARCHAR(4000)           ,
  PRIMARY KEY (ID)
) IN @DB_NAME@.PFSPTTS7;

CREATE UNIQUE INDEX 
 @SCHEMA@.PTN_AUDIT_PK ON 
 @SCHEMA@.PFS_PARTITIONING_AUDIT 
 (ID) 
 USING STOGROUP @STOGRP@;

-- ------------------
-- PFS_PARTITIONING_SEQ
-- ------------------ 
CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_SEQ
     START WITH 1
     INCREMENT BY 1
     NO MAXVALUE
     NO CYCLE
     CACHE 24;

-- Initial data for the PFS_BPEL_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020');

COMMIT;
     