-- Licensed Materials - Property of IBM
-- 5725-A20
-- Copyright IBM Corporation 2015, 2016.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create database and tablespaces for SQL Server UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg PFSDB
-- @SCHEMA@  = the schema name, eg PFSUSER
-- @DB_USER@ = database user for the pfs schema
-- @DB_PASSWORD@ = the database user password
--
--    For a database install with enhanced security:
--    Remove the following three lines in the script:
--
--        -- Add the pfsdb user to the db_owner role
--        EXEC sp_addrolemember 'db_owner', @DB_USER@
--        GO 
--
--    then follow the instructions in the createTables_PFS.sql script.
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i createDatabase_PFS.sql
--
-- ------------------------------------------------------------------------------------
-- create the database
USE master
CREATE DATABASE @DB_NAME@ COLLATE SQL_Latin1_General_CP1_CS_AS
GO

USE master;
-- Create a login for the monitor database user if is does not exist
IF NOT EXISTS (SELECT * FROM syslogins WHERE NAME = '@DB_USER@') CREATE LOGIN @DB_USER@ WITH PASSWORD = '@DB_PASSWORD@', DEFAULT_DATABASE=@DB_NAME@;

-- Create a database user for the monitor user
IF NOT EXISTS (SELECT * FROM sysusers WHERE NAME = '@DB_USER@') CREATE USER @DB_USER@ FOR LOGIN @DB_USER@;
GO

-- Add monitor user the XA JDBC role
EXEC sp_addrolemember [SqlJDBCXAUser], @DB_USER@
GO

USE @DB_NAME@ 

-- Add the user to the PFSDB database
EXEC sp_adduser @DB_USER@
GO

-- Add the pfsdb user to the db_owner role
EXEC sp_addrolemember 'db_owner', @DB_USER@
GO 

IF NOT EXISTS (SELECT * FROM sys.schemas WHERE name = '@SCHEMA@') 
BEGIN
    EXEC( 'CREATE SCHEMA @SCHEMA@' );
END
GO

