-- Licensed Materials - Property of IBM
-- 5725-A20
-- Copyright IBM Corporation 2015, 2016.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Script file to create database and tablespaces for SQL Server UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg PFSDB
-- @SCHEMA@  = the schema name, eg PFSUSER
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of GRANT statements 
--    by replacing the string "--GRANT STMT--" with ""
--
-- @DB_USER@ = database user for the pfs schema, only needed for GRANT statements
--    for database installation with enhanced security
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i createTable_PFS.sql
--
-- ------------------------------------------------------------------------------------
use @DB_NAME@
checkpoint
GO

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.PFS_SAVED_SEARCHES
(
  SEARCH_ID                          BIGINT IDENTITY(100,1)              NOT NULL,
  SEARCH_NAME                        NVARCHAR(256)                     NOT NULL ,
  ORGANIZATION                       NVARCHAR(32)                      NOT NULL ,
  SHARED                             SMALLINT                          NOT NULL ,
  OWNER                              NVARCHAR(128)                     NOT NULL ,
  QUERY                              TEXT                                       ,
  LAST_UPDATED                       DATETIME                          NOT NULL ,
  LAST_UPDATED_BY                    NVARCHAR(128)                     NOT NULL ,
  SHARED_UNIQUE					     AS (CASE WHEN SHARED=1 THEN 1 ELSE SEARCH_ID END),
  PRIMARY KEY ( SEARCH_ID )
)
GO

-- Enforce rule that all shared searches must have a unique name
-- This index is remarked out for SQL Server 2008 compatibility
-- This index will work and is recommended for SQL Server 2008 R2 and later
--CREATE UNIQUE INDEX SAVED_SEARCH_IDX1 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, SHARED_UNIQUE)
--GO

-- Enforce rule that all searches must have a unique name for the creator
CREATE UNIQUE INDEX SAVED_SEARCH_IDX2 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, OWNER)
GO

CREATE INDEX SAVED_SEARCH_IDX3 ON @SCHEMA@.PFS_SAVED_SEARCHES (OWNER, SHARED)
GO

--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PFS_SAVED_SEARCHES TO @DB_USER@;
