-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014, 2015. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg BPMDB
-- @SCHEMA@ = the schema name, eg BPMUSER

-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i create_bpd_change_log.ddl
--
-- ------------------------------------------------------------------------------------

use @DB_NAME@
checkpoint
GO

-- ------------------
-- PFS_BPD_CHANGE_LOG
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG (
	ID                   BIGINT          NOT NULL IDENTITY(1,1),
	TASK_ID              DECIMAL(38,0),
	INSTANCE_ID          DECIMAL(38,0),
	TYPE                 SMALLINT        NOT NULL,
	PARTITION            SMALLINT        NOT NULL,
	ENTRY_TIME           DATETIME        NOT NULL,
	CONSUMER_001         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_002         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_003         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_004         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_005         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_006         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_007         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_008         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_009         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_010         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_011         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_012         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_013         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_014         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_015         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_016         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_017         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_018         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_019         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_020         SMALLINT        NOT NULL DEFAULT 0,
	PRIMARY KEY (ID)
)
GO

CREATE INDEX PFS_BPDCL_IDX_1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (TASK_ID, INSTANCE_ID, CONSUMER_001, TYPE DESC, ENTRY_TIME DESC);
GO

CREATE INDEX PFS_BPDCL_IDX_A1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_001);
GO
CREATE INDEX PFS_BPDCL_IDX_B1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_001, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
GO

CREATE INDEX PFS_BPDCL_IDX_A2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_002);
GO
CREATE INDEX PFS_BPDCL_IDX_B2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_002, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
GO

CREATE INDEX PFS_BPDCL_IDX_A3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_003);
GO
CREATE INDEX PFS_BPDCL_IDX_B3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_003, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
GO

CREATE INDEX PFS_BPDCL_IDX_A4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_004);
GO
CREATE INDEX PFS_BPDCL_IDX_B4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_004, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
GO

CREATE INDEX PFS_BPDCL_IDX_A5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_005);
GO
CREATE INDEX PFS_BPDCL_IDX_B5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_005, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
GO

-- Create these the following indexes if additional consumers of the BPD change log are configured.

--CREATE INDEX PFS_BPDCL_IDX_A6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_006);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_006, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_007);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_007, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_008);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_008, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_009);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_009, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_010);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_010, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_011);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_011, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_012);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_012, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_013);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_013, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_014);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_014, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_015);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_015, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_016);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_016, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_017);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_017, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_018);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_018, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_019);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_019, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO

--CREATE INDEX PFS_BPDCL_IDX_A20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_020);
--GO
--CREATE INDEX PFS_BPDCL_IDX_B20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_020, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC);
--GO


-- ---------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          NVARCHAR(128)   NOT NULL,
	CONSUMER_ID          NVARCHAR(300),
	PRIMARY KEY (COLUMN_NAME)
)
GO

-- -------------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (
	SOURCE_ID            NVARCHAR(128)   NOT NULL,
	CONSUMER_ID          NVARCHAR(300)   NOT NULL,
	START_TIME           DATETIME        NOT NULL,
	END_TIME             DATETIME,
	PROCESSED_TASKS      BIGINT,
	PROCESSED_INSTANCES  BIGINT,
	FAILED_TASKS         BIGINT,
	FAILED_INSTANCES     BIGINT,
	MESSAGE              NVARCHAR(4000),
	PRIMARY KEY (SOURCE_ID, CONSUMER_ID, START_TIME)
)
GO

CREATE INDEX PFS_BCLCL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (SOURCE_ID, CONSUMER_ID, START_TIME, END_TIME, PROCESSED_TASKS)
GO

CREATE INDEX PFS_BCLCL_IDX2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, START_TIME)
GO

-- ------------------
-- PFS_BPD_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL (
  	OPERATION            NVARCHAR(128)    NOT NULL, 
	START_TIME           DATETIME,
	COMPLETION_TIME      DATETIME
)
GO

CREATE UNIQUE INDEX PFS_BPD_CHANGE_LOG_UTIL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL (OPERATION)
GO

CREATE TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID               NVARCHAR(400)           NOT NULL, 
  UNIQUE_ID                         BIGINT                  NOT NULL, 
  EXPIRY                            DATETIME                NOT NULL, 
  TARGET                            NVARCHAR(1024)          NOT NULL, 
  STATE                             NVARCHAR(1024)          NOT NULL,
  PRIMARY KEY (CONTROLLER_GROUP_ID)
)
GO

CREATE UNIQUE NONCLUSTERED INDEX MOD_CONTR_IDX ON @SCHEMA@.PFS_PARTITIONING_CONTROLLER (UNIQUE_ID)
GO

CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AGENT  (
  CONTROLLER_GROUP_ID               NVARCHAR(400)           NOT NULL, 
  UNIQUE_ID                         BIGINT                  NOT NULL, 
  EXPIRY                            DATETIME                NOT NULL, 
  TARGET                            NVARCHAR(1024)          NOT NULL, 
  WEIGHT                            SMALLINT                NOT NULL,
  REQUEST                           NVARCHAR(1024)          NOT NULL,
  REQUEST_SEQ                       BIGINT                  NOT NULL, 
  RANGE_FIRST                       BIGINT                  , 
  RANGE_LAST                        BIGINT                  , 
  ACK_SEQ                           BIGINT                  NOT NULL, 
  PRIMARY KEY (CONTROLLER_GROUP_ID, UNIQUE_ID)
)
GO

CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT  (
  ID                                BIGINT                  IDENTITY(1,1) NOT NULL,
  CONTROLLER_GROUP_ID               NVARCHAR(400)           NOT NULL ,
  ENTRY_TIME                        DATETIME                NOT NULL,
  TARGET                            NVARCHAR(512)           NOT NULL,
  MESSAGE                           NVARCHAR(4000)           ,
  PRIMARY KEY (ID)
)
GO


CREATE TABLE @SCHEMA@.PFS_PARTITIONING_SEQ (
      ID BIGINT IDENTITY(1,1) PRIMARY KEY,
      VALUE VARCHAR(1)
)
GO

CREATE PROCEDURE @SCHEMA@.GetNextModeratorSequence
AS
BEGIN

      DECLARE @NewModSeqValue BIGINT

      SET NOCOUNT ON

      INSERT INTO @SCHEMA@.PFS_PARTITIONING_SEQ (VALUE) values ('A')

      SET @NewModSeqValue = scope_identity()

      DELETE FROM @SCHEMA@.PFS_PARTITIONING_SEQ WITH (READPAST)

RETURN @NewModSeqValue

END
GO
 
-- Initial data for the PFS_BPD_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019')
GO
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020')
GO
