-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@ = the schema name, eg BPMUSER, the same as BPE table
-- @DB_NAME@ = the database name, eg CMNDB
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i create_bpel_change_log.ddl
--
-- ------------------------------------------------------------------------------------

use @DB_NAME@
checkpoint
GO

-- ANSI_PADDING required to not truncate trailing zeros in varbinary columns
SET ANSI_PADDING ON
go

-- ------------------
-- PFS_BPEL_CHANGE_LOG
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
    PKID                 BINARY(16)      NOT NULL ,
    OBJECT_TYPE          INTEGER         NOT NULL ,
    OBJECT_ID            BINARY(16)      NOT NULL ,
    EVENT                INTEGER         NOT NULL ,
    EVENT_TIME           DATETIME        NOT NULL ,
    EVENT_KIND           INTEGER         NOT NULL ,
    PARTITION            INTEGER         NULL ,
    VERSION_ID           SMALLINT        NOT NULL ,
    CONSUMER_001         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_002         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_003         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_004         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_005         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_006         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_007         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_008         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_009         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_010         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_011         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_012         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_013         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_014         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_015         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_016         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_017         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_018         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_019         SMALLINT        NOT NULL DEFAULT 0,
	CONSUMER_020         SMALLINT        NOT NULL DEFAULT 0,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX INDEXER_LOG_P ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
    PKID
)
go


CREATE INDEX IL_OID ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  OBJECT_ID
)
go

CREATE INDEX IL_KND ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  EVENT_KIND
)
go

CREATE INDEX IL_PARTTN ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  PARTITION
)
go

CREATE INDEX BPCCL_IDX1 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_001, PARTITION);
GO
CREATE INDEX BPCCL_IDX2 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_002, PARTITION);
GO
CREATE INDEX BPCCL_IDX3 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_003, PARTITION);
GO
CREATE INDEX BPCCL_IDX4 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_004, PARTITION);
GO
CREATE INDEX BPCCL_IDX5 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_005, PARTITION);
GO
CREATE INDEX BPCCL_IDX6 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_006, PARTITION);
GO
CREATE INDEX BPCCL_IDX7 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_007, PARTITION);
GO
CREATE INDEX BPCCL_IDX8 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_008, PARTITION);
GO
CREATE INDEX BPCCL_IDX9 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_009, PARTITION);
GO
CREATE INDEX BPCCL_IDX10 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_010, PARTITION);
GO

-- disable page locks
sp_indexoption '@SCHEMA@.PFS_BPEL_CHANGE_LOG', 'AllowPageLocks', FALSE
go



-- View: IndexerLog
CREATE VIEW @SCHEMA@.PFS_BPEL_CHANGE_LOG_V(PKID, OBJECT_TYPE, OBJECT_ID, EVENT, EVENT_TIME, KIND, PARTITION ) AS
 SELECT @SCHEMA@.PFS_BPEL_CHANGE_LOG.PKID, @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_TYPE, @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_ID, @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT, @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_TIME, @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_KIND, @SCHEMA@.PFS_BPEL_CHANGE_LOG.PARTITION
 FROM @SCHEMA@.PFS_BPEL_CHANGE_LOG
go

-- ---------------------------
-- PFS_BPEL_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          NVARCHAR(128)   NOT NULL,
	CONSUMER_ID          NVARCHAR(256),
	PRIMARY KEY (COLUMN_NAME)
)
GO

-- -------------------------------
-- PFS_BPEL_CHANGE_LOG_CONSMR_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (
	SOURCE_ID            NVARCHAR(128)   NOT NULL,
	CONSUMER_ID          NVARCHAR(256)   NOT NULL,
	START_TIME           DATETIME        NOT NULL,
	END_TIME             DATETIME,
	PROCESSED_TASKS      BIGINT,
	PROCESSED_INSTANCES  BIGINT,
	FAILED_TASKS         BIGINT,
	FAILED_INSTANCES     BIGINT,
	MESSAGE              NVARCHAR(4000),
	PRIMARY KEY (SOURCE_ID, CONSUMER_ID, START_TIME)
)
GO

CREATE INDEX PFS_BCLCL_IDX0 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, END_TIME)
GO

CREATE INDEX PFS_BCLCL_IDX1 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (END_TIME)
GO

-- ------------------
-- PFS_BPEL_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_UTIL (
  	OPERATION            NVARCHAR(128)    NOT NULL, 
	START_TIME           DATETIME,
	COMPLETION_TIME      DATETIME
)
GO

-- ------------------
-- PFS_PARTITIONING_CONTROLLER
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID               NVARCHAR(256)           NOT NULL, 
  UNIQUE_ID                         BIGINT                  NOT NULL, 
  EXPIRY                            DATETIME                NOT NULL, 
  TARGET                            NVARCHAR(512)          NOT NULL, 
  STATE                             NVARCHAR(1024)          NOT NULL,
  PRIMARY KEY (CONTROLLER_GROUP_ID)
)
GO

CREATE UNIQUE NONCLUSTERED INDEX MOD_CONTR_IDX ON @SCHEMA@.PFS_PARTITIONING_CONTROLLER (UNIQUE_ID)
GO

-- ------------------
-- PFS_PARTITIONING_AGENT
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AGENT  (
  CONTROLLER_GROUP_ID               NVARCHAR(256)           NOT NULL, 
  UNIQUE_ID                         BIGINT                  NOT NULL, 
  EXPIRY                            DATETIME                NOT NULL, 
  TARGET                            NVARCHAR(1024)          NOT NULL, 
  WEIGHT                            SMALLINT                NOT NULL,
  REQUEST                           NVARCHAR(1024)          NOT NULL,
  REQUEST_SEQ                       BIGINT                  NOT NULL, 
  RANGE_FIRST                       BIGINT                  , 
  RANGE_LAST                        BIGINT                  , 
  ACK_SEQ                           BIGINT                  NOT NULL, 
  PRIMARY KEY (CONTROLLER_GROUP_ID, UNIQUE_ID)
)
GO

-- ------------------
-- PFS_PARTITIONING_AUDIT
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT  (
  ID                                BIGINT                  IDENTITY(1,1) NOT NULL,
  CONTROLLER_GROUP_ID               NVARCHAR(256)           NOT NULL ,
  ENTRY_TIME                        DATETIME                NOT NULL,
  TARGET                            NVARCHAR(512)           NOT NULL,
  MESSAGE                           NVARCHAR(4000)           ,
  PRIMARY KEY (ID)
)
GO

-- ------------------
-- PFS_PARTITIONING_SEQ
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_SEQ (
      ID BIGINT IDENTITY(1,1) PRIMARY KEY,
      VALUE VARCHAR(1)
)
GO

CREATE PROCEDURE @SCHEMA@.GetNextModeratorSequence
AS
BEGIN

      DECLARE @NewModSeqValue BIGINT

      SET NOCOUNT ON

      INSERT INTO @SCHEMA@.PFS_PARTITIONING_SEQ (VALUE) values ('A')

      SET @NewModSeqValue = scope_identity()

      DELETE FROM @SCHEMA@.PFS_PARTITIONING_SEQ WITH (READPAST)

RETURN @NewModSeqValue

END
GO

-- Initial data for the PFS_BPEL_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019')
GO
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020')
GO
