-- Licensed Materials - Property of IBM
-- 5725-A20
-- Copyright IBM Corporation 2015, 2016.  All Rights Reserved.
-- US Government Users Restricted Rights - Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.
-- ------------------------------------------------------------------------------------
--
-- Scriptfile to create schema (tables) for Oracle
--
---------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script: 
-- @SCHEMA@ = the schema owner, eg PFSDB
-- @TAB_TS@ - tablespace for data, e.g. PFSDATA
-- @IDX_TS@ - tablespace for indexes, e.g. PFSIDX
--
--    For a database install with enhanced security:
--    Scroll to the bottom of the file and un-comment the series of GRANT statements 
--    by replacing the string "--GRANT STMT--" with ""
--
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @createTable_PFS.sql
--
-- ------------------------------------------------------------------------------------

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.PFS_SAVED_SEARCHES
(
  SEARCH_ID                          NUMBER(20,0)         NOT NULL ,
  SEARCH_NAME                        VARCHAR2(256)        NOT NULL ,
  ORGANIZATION                       VARCHAR2(32)         NOT NULL ,
  SHARED                             NUMBER(5,0)          NOT NULL ,
  OWNER                              VARCHAR2(128)        NOT NULL ,
  QUERY                              CLOB                          ,
  LAST_UPDATED                       TIMESTAMP            NOT NULL ,
  LAST_UPDATED_BY                    VARCHAR2(128)        NOT NULL,
  SHARED_UNIQUE					     NUMBER(20,0) GENERATED ALWAYS AS (CASE WHEN SHARED=1 THEN 1 ELSE SEARCH_ID END)
) TABLESPACE @TAB_TS@ 
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_SAVED_SEARCHES ADD
(
  PRIMARY KEY ( SEARCH_ID )
  USING INDEX TABLESPACE @IDX_TS@
);

-- Enforce rule that all shared searches must have a unique name
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX1 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, SHARED_UNIQUE) TABLESPACE @IDX_TS@;

-- Enforce rule that all searches must have a unique name for the creator
CREATE UNIQUE INDEX @SCHEMA@.SAVED_SEARCH_IDX2 ON @SCHEMA@.PFS_SAVED_SEARCHES (SEARCH_NAME, OWNER) TABLESPACE @IDX_TS@;

CREATE INDEX @SCHEMA@.SAVED_SEARCH_IDX3 ON @SCHEMA@.PFS_SAVED_SEARCHES (OWNER, SHARED) TABLESPACE @IDX_TS@;

CREATE SEQUENCE @SCHEMA@.PFS_SAVED_SEARCHES_SEQ INCREMENT BY 1 START WITH 100 NOCYCLE ORDER;


--GRANT STMT-- GRANT SELECT, INSERT, UPDATE, DELETE ON @SCHEMA@.PFS_SAVED_SEARCHES TO @SCHEMA@;
--GRANT STMT-- GRANT SELECT ON @SCHEMA@.PFS_SAVED_SEARCHES_SEQ TO @SCHEMA@;

QUIT
