-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014, 2015. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg BPMDB

-- Tablespaces may be specified by uncommenting the tablespace line
-- at the end of each table definition.  
-- Note:  Tablespaces must be manually created before executing the script.
-- @TAB_TS@ - tablespace for data, this is an optional parameter
-- @IDX_TS@ - tablespace for indexes, this is an optional parameter
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @create_bpd_change_log.ddl
--
-- ------------------------------------------------------------------------------------


CREATE SEQUENCE @SCHEMA@.PFS_CHANGE_LOG_SEQ INCREMENT BY 1 START WITH 1000 NOMINVALUE NOMAXVALUE NOCYCLE CACHE 20 ORDER;

-- ------------------
-- PFS_BPD_CHANGE_LOG
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG (
	ID                   NUMBER(12,0)    NOT NULL,
	TASK_ID              NUMBER(12,0),
	INSTANCE_ID          NUMBER(12,0),
	TYPE                 NUMBER(5,0)     NOT NULL,
	PARTITION            NUMBER(5,0)     NOT NULL,
	ENTRY_TIME           TIMESTAMP       NOT NULL,
	CONSUMER_001         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_002         NUMBER(5,0)     DEFAULT '0' NOT NULL ,
	CONSUMER_003         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_004         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_005         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_006         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_007         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_008         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_009         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_010         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_011         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_012         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_013         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_014         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_015         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_016         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_017         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_018         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_019         NUMBER(5,0)     DEFAULT '0' NOT NULL,
	CONSUMER_020         NUMBER(5,0)     DEFAULT '0' NOT NULL
)
-- TABLESPACE @TAB_TS@
;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCL_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG(ID)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (TASK_ID, INSTANCE_ID, CONSUMER_001, TYPE DESC, ENTRY_TIME DESC)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_001)
-- TABLESPACE @IDX_TS@
;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_001, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_002)
-- TABLESPACE @IDX_TS@
;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_002, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_003)
-- TABLESPACE @IDX_TS@
;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_003, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_004)
-- TABLESPACE @IDX_TS@
;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_004, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_005)
-- TABLESPACE @IDX_TS@
;
CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_005, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
;

-- Create these the following indexes if additional consumers of the BPD change log are configured.

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_006)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_006, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_007)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_007, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_008)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_008, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_009)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_009, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_010)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_010, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_011)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_011, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_012)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_012, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_013)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_013, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_014)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_014, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_015)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_015, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_016)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_016, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_017)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_017, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_018)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_018, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_019)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_019, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;

--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_A20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (INSTANCE_ID, TASK_ID, TYPE, PARTITION, CONSUMER_020)
-- TABLESPACE @IDX_TS@
--;
--CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_020, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
-- TABLESPACE @IDX_TS@
--;


-- ---------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          VARCHAR2(128)    NOT NULL,
	CONSUMER_ID          VARCHAR2(384)
)
-- TABLESPACE @TAB_TS@
;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLC_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME)
-- TABLESPACE @IDX_TS@
;		

-- -------------------------------
-- PFS_BPD_CHANGE_LOG_CONSUMER_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (
	SOURCE_ID            VARCHAR2(128)    NOT NULL,
	CONSUMER_ID          VARCHAR2(384)    NOT NULL,
	START_TIME           TIMESTAMP        NOT NULL,
	END_TIME             TIMESTAMP,
	PROCESSED_TASKS      NUMBER(12,0),
	PROCESSED_INSTANCES  NUMBER(12,0),
	FAILED_TASKS         NUMBER(12,0),
	FAILED_INSTANCES     NUMBER(12,0),
	MESSAGE              VARCHAR2(4000)
)
-- TABLESPACE @TAB_TS@
;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BCLCL_PK ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG(SOURCE_ID, CONSUMER_ID, START_TIME)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (SOURCE_ID, CONSUMER_ID, START_TIME, END_TIME, PROCESSED_TASKS)
-- TABLESPACE @IDX_TS@
;

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, START_TIME)
-- TABLESPACE @IDX_TS@
;

-- ------------------
-- PFS_BPD_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL (
  	OPERATION            VARCHAR2(128)    NOT NULL, 
	START_TIME           TIMESTAMP,
	COMPLETION_TIME      TIMESTAMP
)
-- TABLESPACE @TAB_TS@
;

CREATE UNIQUE INDEX @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL(OPERATION)
-- TABLESPACE @IDX_TS@
;

CREATE TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID               VARCHAR2(512)           NOT NULL, 
  UNIQUE_ID                         NUMBER(20,0)            NOT NULL, 
  EXPIRY                            TIMESTAMP               NOT NULL, 
  TARGET                            VARCHAR2(1024)          NOT NULL, 
  STATE                             VARCHAR2(1024)          NOT NULL
)
-- TABLESPACE @TAB_TS@
;

ALTER TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER ADD
(
  PRIMARY KEY ( CONTROLLER_GROUP_ID )
--  USING INDEX TABLESPACE @IDX_TS@
);

CREATE UNIQUE INDEX @SCHEMA@.MOD_CONTROL_IDX ON @SCHEMA@.PFS_PARTITIONING_CONTROLLER  (UNIQUE_ID)
-- TABLESPACE @IDX_TS@
;
  
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AGENT  (
  CONTROLLER_GROUP_ID               VARCHAR2(512)           NOT NULL, 
  UNIQUE_ID                         NUMBER(20,0)            NOT NULL, 
  EXPIRY                            TIMESTAMP               NOT NULL, 
  TARGET                            VARCHAR2(1024)          NOT NULL, 
  WEIGHT                            NUMBER(5,0)             NOT NULL,
  REQUEST                           VARCHAR2(1024)          NOT NULL,
  REQUEST_SEQ                       NUMBER(20,0)            NOT NULL, 
  RANGE_FIRST                       NUMBER(20,0)                    , 
  RANGE_LAST                        NUMBER(20,0)                    , 
  ACK_SEQ                           NUMBER(20,0)            NOT NULL
)
-- TABLESPACE @TAB_TS@
;


CREATE INDEX @SCHEMA@.PFS_PARTITIONING_AGENT_IDX ON @SCHEMA@.PFS_PARTITIONING_AGENT 
  (CONTROLLER_GROUP_ID, EXPIRY, REQUEST)
-- TABLESPACE @IDX_TS@
;

ALTER TABLE @SCHEMA@.PFS_PARTITIONING_AGENT ADD
(
  PRIMARY KEY ( CONTROLLER_GROUP_ID, UNIQUE_ID )
--  USING INDEX TABLESPACE @IDX_TS@
);

CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT  (
  ID                                NUMBER(20,0)            NOT NULL,
  CONTROLLER_GROUP_ID               VARCHAR2(512)           NOT NULL,
  ENTRY_TIME                        TIMESTAMP               NOT NULL,
  TARGET                            VARCHAR2(512)           NOT NULL,
  MESSAGE                           VARCHAR2(4000)
)
-- TABLESPACE @TAB_TS@
;
  
ALTER TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT ADD
(
  PRIMARY KEY ( ID )
--  USING INDEX TABLESPACE @IDX_TS@
);

CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_AUDIT_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;

CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;


-- Initial data for the PFS_BPD_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019');
INSERT INTO @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020');

COMMIT;
