-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2014. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg BPMUSER, the same as BPE table

-- Tablespaces may be specified by uncommenting the tablespace line
-- at the end of each table definition.  
-- Note:  Tablespaces must be manually created before executing the script.
-- @INSTANCE@ = The tablespace name of table, you can share the same tablespace as other BPE table
-- @INDEXTS@ = The tablespace name of index, you can share the same tablespace as other BPE index
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @create_bpel_change_log.ddl
--
-- ------------------------------------------------------------------------------------


-------------------
-- Create PFS_BPEL_CHANGE_LOG table --
-------------------

CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  PKID                               RAW(16)              NOT NULL ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  OBJECT_ID                          RAW(16)              NOT NULL ,
  EVENT                              NUMBER(10,0)         NOT NULL ,
  EVENT_TIME                         TIMESTAMP            NOT NULL ,
  EVENT_KIND                         NUMBER(10,0)         NOT NULL ,
  PARTITION                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL ,
  CONSUMER_001         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_002         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_003         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_004         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_005         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_006         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_007         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_008         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_009         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_010         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_011         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_012         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_013         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_014         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_015         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_016         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_017         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_018         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_019         NUMBER(5,0)     DEFAULT '0' NOT NULL,
  CONSUMER_020         NUMBER(5,0)     DEFAULT '0' NOT NULL
) 
-- TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG ADD(
  PRIMARY KEY ( PKID )
--  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.IL_OID ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  OBJECT_ID
) 
-- TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.IL_KND ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  EVENT_KIND
) 
-- TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.IL_PARTTN ON @SCHEMA@.PFS_BPEL_CHANGE_LOG
(
  PARTITION
) 
-- TABLESPACE @INDEXTS@
  LOGGING;

CREATE INDEX @SCHEMA@.BPCCL_IDX1 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_001, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX2 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_002, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX3 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_003, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX4 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_004, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX5 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_005, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX6 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_006, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX7 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_007, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX8 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_008, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX9 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_009, PARTITION)
-- TABLESPACE @INDEXTS@
;
CREATE INDEX @SCHEMA@.BPCCL_IDX10 ON @SCHEMA@.PFS_BPEL_CHANGE_LOG (CONSUMER_010, PARTITION)
-- TABLESPACE @INDEXTS@
;  

-- View: IndexerLog
CREATE VIEW @SCHEMA@.PFS_BPEL_CHANGE_LOG_V(PKID, OBJECT_TYPE, OBJECT_ID, EVENT, EVENT_TIME, KIND, PARTITION ) AS
 SELECT
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.PKID,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_TYPE,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.OBJECT_ID,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_TIME,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.EVENT_KIND,
   @SCHEMA@.PFS_BPEL_CHANGE_LOG.PARTITION
 FROM @SCHEMA@.PFS_BPEL_CHANGE_LOG;


 -- ---------------------------
-- PFS_BPEL_CHANGE_LOG_CONSUMER
-- ---------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER (
	COLUMN_NAME          VARCHAR2(128)    NOT NULL,
	CONSUMER_ID          VARCHAR2(256)
) 
-- TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER ADD(
  PRIMARY KEY ( COLUMN_NAME )
--  USING INDEX TABLESPACE @INDEXTS@
);

-- -------------------------------
-- PFS_BPEL_CHANGE_LOG_CONSMR_LOG
-- -------------------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG (
    SOURCE_ID            VARCHAR2(128)    NOT NULL,
	CONSUMER_ID          VARCHAR2(256)    NOT NULL,
	START_TIME           TIMESTAMP        NOT NULL,
	END_TIME             TIMESTAMP,
	PROCESSED_TASKS      NUMBER(12,0),
	PROCESSED_INSTANCES  NUMBER(12,0),
	FAILED_TASKS         NUMBER(12,0),
	FAILED_INSTANCES     NUMBER(12,0),
	MESSAGE              VARCHAR2(4000)
) 
-- TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG ADD(
  PRIMARY KEY (SOURCE_ID, CONSUMER_ID, START_TIME )
--  USING INDEX TABLESPACE @INDEXTS@
);

CREATE INDEX @SCHEMA@.ICID_ENDTIME ON @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSMR_LOG
(
  CONSUMER_ID, END_TIME
) 
-- TABLESPACE @INDEXTS@
  LOGGING;

-- ------------------
-- PFS_BPEL_CHANGE_LOG_UTIL
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPEL_CHANGE_LOG_UTIL (
  	OPERATION            VARCHAR2(128)    NOT NULL, 
	START_TIME           TIMESTAMP,
	COMPLETION_TIME      TIMESTAMP
) 
-- TABLESPACE @INSTANCE@
  LOGGING;

-- ------------------
-- PFS_PARTITIONING_CONTROLLER
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER  (
  CONTROLLER_GROUP_ID               VARCHAR2(256)           NOT NULL, 
  UNIQUE_ID                         NUMBER(20,0)            NOT NULL, 
  EXPIRY                            TIMESTAMP               NOT NULL, 
  TARGET                            VARCHAR2(1024)          NOT NULL, 
  STATE                             VARCHAR2(1024)          NOT NULL
) 
-- TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_PARTITIONING_CONTROLLER ADD
(
  PRIMARY KEY ( CONTROLLER_GROUP_ID )
--  USING INDEX TABLESPACE @INDEXTS@
); 

CREATE UNIQUE INDEX @SCHEMA@.MOD_CONTROL_IDX ON @SCHEMA@.PFS_PARTITIONING_CONTROLLER 
(
  UNIQUE_ID
)
-- TABLESPACE @INDEXTS@
  LOGGING;
 
-- ------------------
-- PFS_PARTITIONING_AGENT
-- ------------------  
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AGENT  (
  CONTROLLER_GROUP_ID               VARCHAR2(256)           NOT NULL, 
  UNIQUE_ID                         NUMBER(20,0)            NOT NULL, 
  EXPIRY                            TIMESTAMP               NOT NULL, 
  TARGET                            VARCHAR2(512)          NOT NULL, 
  WEIGHT                            NUMBER(5,0)             NOT NULL,
  REQUEST                           VARCHAR2(1024)          NOT NULL,
  REQUEST_SEQ                       NUMBER(20,0)            NOT NULL, 
  RANGE_FIRST                       NUMBER(20,0)                    , 
  RANGE_LAST                        NUMBER(20,0)                    , 
  ACK_SEQ                           NUMBER(20,0)            NOT NULL
)
-- TABLESPACE @INSTANCE@
  LOGGING;


CREATE INDEX @SCHEMA@.PFS_PARTITIONING_AGENT_IDX ON @SCHEMA@.PFS_PARTITIONING_AGENT 
(
  CONTROLLER_GROUP_ID, EXPIRY, REQUEST
)
-- TABLESPACE @INDEXTS@
  LOGGING;

ALTER TABLE @SCHEMA@.PFS_PARTITIONING_AGENT ADD
(
  PRIMARY KEY ( CONTROLLER_GROUP_ID, UNIQUE_ID )
--  USING INDEX TABLESPACE @INDEXTS@
);

-- ------------------
-- PFS_PARTITIONING_AUDIT
-- ------------------
CREATE TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT  (
  ID                                NUMBER(20,0)            NOT NULL,
  CONTROLLER_GROUP_ID               VARCHAR2(256)           NOT NULL,
  ENTRY_TIME                        TIMESTAMP               NOT NULL,
  TARGET                            VARCHAR2(512)           NOT NULL,
  MESSAGE                           VARCHAR2(4000)
)
-- TABLESPACE @INSTANCE@
  LOGGING;
  
ALTER TABLE @SCHEMA@.PFS_PARTITIONING_AUDIT ADD
(
  PRIMARY KEY ( ID )
--  USING INDEX TABLESPACE @INDEXTS@
);

-- ------------------
-- PFS_PARTITIONING_SEQ
-- ------------------
CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_AUDIT_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;

CREATE SEQUENCE @SCHEMA@.PFS_PARTITIONING_SEQ INCREMENT BY 1 START WITH 1 NOCYCLE ORDER;

CREATE SEQUENCE @SCHEMA@.PFS_CHANGE_LOG_SEQ INCREMENT BY 1 START WITH 1000 NOMINVALUE NOMAXVALUE NOCYCLE CACHE 20 ORDER;

-- Initial data for the PFS_BPEL_CHANGE_LOG_CONSUMER table
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_001');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_002');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_003');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_004');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_005');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_006');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_007');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_008');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_009');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_010');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_011');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_012');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_013');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_014');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_015');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_016');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_017');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_018');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_019');
INSERT INTO @SCHEMA@.PFS_BPEL_CHANGE_LOG_CONSUMER(COLUMN_NAME) VALUES ('CONSUMER_020');

COMMIT;