-- Licensed Materials - Property of IBM
-- 5725-C94, 5725-C95, 5725-C96
-- Copyright IBM Corporation 2016. All Rights Reserved.
-- US Government Users Restricted Rights- Use, duplication or disclosure
-- restricted by GSA ADP Schedule Contract with IBM Corp.

-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg BPMDB

-- Tablespaces may be specified by uncommenting the tablespace line
-- at the end of each table definition.  
-- Note:  Tablespaces must be manually created before executing the script.
-- @TAB_TS@ - tablespace for data, this is an optional parameter.  Tablespaces can be enabled by removing the comment marker before TABLESPACE lines.
-- @IDX_TS@ - tablespace for indexes, this is an optional parameter. Tablespaces can be enabled by removing the comment marker before TABLESPACE amd USING INDEX TABLESPACE lines.
--
-- Run the script in SQL*Plus.
--
-- USAGE:  sqlplus system/passw0rd@orcl @upgrade_bpd_change_log_8570.sql
--
-- ------------------------------------------------------------------------------------

CREATE INDEX @SCHEMA@.PFS_BCLCL_IDX2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG_CONSMR_LOG (CONSUMER_ID, START_TIME)
--TABLESPACE @IDX_TS@
;


CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (TASK_ID, INSTANCE_ID, CONSUMER_001, TYPE DESC, ENTRY_TIME DESC)
--TABLESPACE @IDX_TS@
;

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B1' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B1';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B1 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_001, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) 
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B2' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B2';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B2 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_002, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
	  --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B3' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B3';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B3 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_003, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) 
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B4' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B4';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B4 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_004, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B5' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B5';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B5 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_005, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B6' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B6';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B6 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_006, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC) 
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B7' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B7';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B7 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_007, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B8' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B8';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B8 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_008, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B9' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B9';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B9 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_009, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B10' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B10';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B10 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_010, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B11' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B11';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B11 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_011, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B12' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B12';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B12 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_012, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B13' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B13';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B13 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_013, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B14' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B14';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B14 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_014, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B15' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B15';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B15 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_015, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B16' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B16';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B16 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_016, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B17' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B17';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B17 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_017, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B18' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B18';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B18 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_018, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B19' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B19';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B19 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_019, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

DECLARE
  ts_exists INTEGER;
BEGIN
  SELECT COUNT(1) INTO ts_exists FROM DBA_INDEXES WHERE INDEX_NAME = 'PFS_BPDCL_IDX_B20' AND TABLE_NAME = 'PFS_BPD_CHANGE_LOG' AND TABLE_OWNER = '@SCHEMA@' AND TABLE_TYPE = 'TABLE';
  IF ts_exists = 1 THEN
      EXECUTE IMMEDIATE 'DROP INDEX @SCHEMA@.PFS_BPDCL_IDX_B20';
      EXECUTE IMMEDIATE 'CREATE INDEX @SCHEMA@.PFS_BPDCL_IDX_B20 ON @SCHEMA@.PFS_BPD_CHANGE_LOG (CONSUMER_020, PARTITION, INSTANCE_ID, TASK_ID, TYPE DESC)
      --TABLESPACE @IDX_TS@
      ';
  END IF;
END;
/

CREATE UNIQUE INDEX @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL_IDX ON @SCHEMA@.PFS_BPD_CHANGE_LOG_UTIL(OPERATION)
--TABLESPACE @IDX_TS@
;

-- ------------------
-- PFS_BPD_SCHEMA_VERSION
-- ------------------
CREATE TABLE @SCHEMA@.PFS_BPD_SCHEMA_VERSION
(
  SCHEMA_VERSION                     NUMBER(10,0)        NOT NULL 
) 
--TABLESPACE @TAB_TS@
;

ALTER TABLE @SCHEMA@.PFS_BPD_SCHEMA_VERSION ADD
(
  PRIMARY KEY ( SCHEMA_VERSION )
--USING INDEX TABLESPACE @IDX_TS@
);

-- set schema version to: 8570
INSERT INTO @SCHEMA@.PFS_BPD_SCHEMA_VERSION (SCHEMA_VERSION) VALUES( 8570 );

COMMIT;
