#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94, 5725-C95, 5725-C96
# (C) Copyright IBM Corporation 2012, 2013. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os, sys

def showKeystoreList():
    keyStoreList = AdminTask.listKeyStores('[-all true -keyStoreUsage SSLKeys ]').split("\r\n")
    print keyStoreList
    for keyStore in keyStoreList:
        print "keyStore: " +  keyStore
    return keyStoreList    
#end of showKeystoreList

def createKeyStore(keyStoreName, scopeName, keyStoreLocation, keyStorePassword):
    print "createKeyStore"
    result = AdminTask.createKeyStore(['-keyStoreName', keyStoreName, '-scopeName', scopeName, '-keyStoreDescription', 'Federated Portal Server KeyStore', '-keyStoreLocation', keyStoreLocation, '-keyStorePassword', keyStorePassword, '-keyStorePasswordVerify', keyStorePassword, '-keyStoreType', 'JKS', '-keyStoreInitAtStartup false -keyStoreReadOnly false -keyStoreStashFile false -keyStoreUsage SSLKeys'])
    print result + " successfully created"
#end of createKeyStore

def listPersonalCertificates(keyStoreName, keyStoreScope):
    personalCertificatesList = AdminTask.listPersonalCertificates(['-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope ]).split("\r\n")
    for personalCertificates in personalCertificatesList:
        print "personalCertificates: " +  personalCertificates
    return personalCertificatesList 
#end of listPersonalCertificates 

def createChainedCertificate(keyStoreName, keyStoreScope, certificateAlias, certificateCommonName):
    print "createChainedCertificate"
    result = AdminTask.createChainedCertificate(['-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope, '-certificateAlias', certificateAlias, '-rootCertificateAlias root -certificateSize 2048 -certificateCommonName', certificateCommonName, '-certificateOrganization ibm -certificateOrganizationalUnit fp -certificateLocality -certificateState -certificateZip -certificateCountry US -certificateValidDays 365' ])
    print result + " successfully created"
      
#end of createChainedCertificate 

def getCertificate(keyStoreName, keyStoreScope, certificateAlias):
    tempCertList = AdminTask.getCertificate(['-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope, '-certificateAlias', certificateAlias ])
    certList =  tempCertList.split("\r\n")
    for cert in certList:
        print "Certificate: " +  cert
    return certList 
#end of getCertificate

def getCertificateChain(keyStoreName, keyStoreScope, certificateAlias):
    tempCertChainList = AdminTask.getCertificateChain(['-certificateAlias', certificateAlias, '-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope])
    certChainList =  tempCertChainList.split("\r\n")
    for certChain in certChainList:
        print "CertificateChain: " +  certChain
    return certChainList 
#end of getCertificate

def listSignerCertificates(keyStoreName, keyStoreScope):
    tempSignerCertificatesList = AdminTask.listSignerCertificates(['-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope])
    signerCertificatesList =  tempSignerCertificatesList.split("\r\n")
    for signerCertificatesList in signerCertificatesList:
        print "signerCertificatesList: " +  signerCertificatesList
    return signerCertificatesList 
#end of listSignerCertificates 

def retrieveSignerFromPort(keyStoreName, keyStoreScope, certificateAlias, bpmHost, bpmPort):
    print "retrieveSignerFromPort"
    result = AdminTask.retrieveSignerFromPort(['-keyStoreName', keyStoreName, '-keyStoreScope', keyStoreScope, '-host', str(bpmHost), '-port', bpmPort, '-certificateAlias', certificateAlias, '-sslConfigName CellDefaultSSLSettings -sslConfigScopeName', keyStoreScope])
    print result + " successfully completed" 
#end of retrieveSignerFromPort
 
def showSSO():
    result = AdminTask.getSingleSignon()
    print "Current Single Sign-On configuration: " + result
    return result
#end of showSSO

def enableSSO(domainName, requiresSSL):
    result = AdminTask.configureSingleSignon(['-enable', 'true', '-domainName', domainName, '-requiresSSL', requiresSSL])
    print "Note: the default value of requiresSSL is false"
    return result
#end of enableSSO

def disableSSO():
    result = AdminTask.configureSingleSignon(['-enable', 'false'])
    return result   
#end of disableSSO

def importLTPAKeys(keyFile, password):
    result = AdminTask.importLTPAKeys(['-ltpaKeyFile', keyFile, '-password', password])
    return result
#end of importLTPAKeys

def exportLTPAKeys(keyFile, password):
    result = AdminTask.exportLTPAKeys(['-ltpaKeyFile', keyFile, '-password', password])
    return result
#end of exportLTPAKeys

def helpPrint():
    print ""
    print "Input operation usage: createKeyStore, showKeystoreList, addSignerCertificate, getKeystoreInfo, deleteKeyStore, showSSO, disableSSO, enableSSO, importLTPAKeys, exportLTPAKeys, help"
    print "-createKeyStore arguments: cellName, keyStoreName, keyStorePassword, keyStoreLocation, certificateAlias, certificateCommonName"
    print "-showKeystoreList arguments: "
    print "-addSignerCertificate arguments: cellName, keyStoreName, bpmSignerCertAlias, bpmSignerCertHost, bpmSignerCertPort"
    print "-getKeystoreInfo arguments: cellName, keyStoreName, certificateAlias"
    print "-deleteKeyStore arguments: cellName, keyStoreName"
    print "-showSSO arguments: "
    print "-disableSSO arguments: "
    print "-enableSSO arguments: domainName, requiresSSL"
    print "-importLTPAKeys arguments: keyFile, password"
    print "-exportLTPAKeys arguments: keyFile, password"
#end of helpPrint 

def saveChange():
    # commit all the changes above
    AdminConfig.save()
    print "Saving configuration changes..." 
#end of saveChange

def deleteKeyStore(keyStoreName, scopeName):
    print "deleteKeyStore"
    result = AdminTask.deleteKeyStore(['-keyStoreName', keyStoreName, '-scopeName', scopeName])
    print result + " successfully completed"  
#end of removeKeyStore

#------------------------------------------------------------------------------
# Main
#------------------------------------------------------------------------------
SEPARATOR=os.sep
 

if (len(sys.argv) < 1):
    helpPrint()
    sys.exit()
elif (sys.argv[0]=="help"):
    helpPrint()
elif (sys.argv[0]=="showKeystoreList"):
    print "Starting script..."
    print ""
    myKeyStoreList = showKeystoreList()
    print ""
    print "Operation completed successfully" 
elif (sys.argv[0]=="createKeyStore"):
    if (len(sys.argv) < 7):
        print "createKeyStore arguments: cellName, keyStoreName, keyStorePassword, keyStoreLocation, certificateAlias, certificateCommonName"
        sys.exit()
    else:
        print "Starting script..."
        print ""
        #parse the parameters from command line
        cellName=sys.argv[1]
        keyStoreName=sys.argv[2]
        keyStorePassword = sys.argv[3]
        keyStoreLocation = sys.argv[4]
        certificateAlias = sys.argv[5]
        certificateCommonName = sys.argv[6]
        print "Input arguments: cellName: " + cellName + ", keyStoreName: " + keyStoreName + ", keyStorePassword: " + keyStorePassword + ", keyStoreLocation: " + keyStoreLocation + ", certificateAlias: " + certificateAlias + ", certificateCommonName: " + certificateCommonName
        print ""
        keyStoreFile = keyStoreLocation+ SEPARATOR +keyStoreName+'.jks'
        keyStoreScope = '(cell):'+cellName
        createKeyStore(keyStoreName, keyStoreScope, keyStoreFile, keyStorePassword)
        createChainedCertificate(keyStoreName, keyStoreScope, certificateAlias, certificateCommonName)
        print keyStoreFile + " created successfully"
        saveChange()
        print ""
        print "Operation completed successfully"
elif (sys.argv[0]=="addSignerCertificate"):
    if (len(sys.argv) < 6):
        print "addSignerCertificate arguments: cellName, keyStoreName, bpmSignerCertAlias, bpmSignerCertHost, bpmSignerCertPort"
        sys.exit()
    else:
        print "Starting script..."
        print ""
        #parse the parameters from command line
        cellName = sys.argv[1]
        keyStoreName=sys.argv[2]
        certificateAlias = sys.argv[3]
        bpmHost = sys.argv[4]
        bpmPort = sys.argv[5] 
        print "Input arguments: cellName: " + cellName + ", keyStoreName: " + keyStoreName + ", bpmSignerCertAlias: " + certificateAlias + ", bpmSignerCertHost: " + bpmHost + ", bpmSignerCertPort: " + bpmPort
        print ""
        keyStoreFile = keyStoreName+'.jks'
        keyStoreScope = '(cell):'+cellName
        retrieveSignerFromPort(keyStoreName, keyStoreScope, certificateAlias, bpmHost, bpmPort)
        listSignerCertificates(keyStoreName, keyStoreScope)
        print certificateAlias + " is added into " + keyStoreFile + " created successfully"
        saveChange()
        print ""
        print "Operation completed successfully"
elif (sys.argv[0]=="getKeystoreInfo"):
    if (len(sys.argv) < 4):
        print "getKeystoreInfo arguments: cellName, keyStoreName, certificateAlias"
        sys.exit()
    else:
        print "Starting script..."
        print ""
        #parse the parameters from command line
        cellName=sys.argv[1]
        keyStoreName=sys.argv[2]
        certificateAlias = sys.argv[3]
        print "Input arguments: cellName: " + cellName + ", keyStoreName: " + keyStoreName + ", certificateAlias" + certificateAlias
        keyStoreScope = '(cell):'+cellName
        listPersonalCertificates(keyStoreName, keyStoreScope)
        print ""
        getCertificateChain(keyStoreName, keyStoreScope, certificateAlias)
        print ""
        listSignerCertificates(keyStoreName, keyStoreScope)
        print ""
        print "Operation completed successfully"
elif (sys.argv[0]=="deleteKeyStore"):
    if (len(sys.argv) < 3):
        print "getKeystoreInfo arguments: cellName, keyStoreName"
        sys.exit()
    else:
        print "Starting script..."
        print ""
        #parse the parameters from command line
        cellName=sys.argv[1]
        keyStoreName=sys.argv[2]
        print "Input arguments: cellName: " + cellName + ", keyStoreName: " + keyStoreName
        keyStoreScope = '(cell):'+cellName
        print ""
        deleteKeyStore(keyStoreName, keyStoreScope)
        saveChange()
        print ""
        print "Operation completed successfully"
elif (sys.argv[0]=="showSSO"):
	print ""
	print showSSO()
	print "Operation completed successfully"
	sys.exit()
elif (sys.argv[0]=="enableSSO"):
	print ""
	if (len(sys.argv) > 3):
	    print "enableSSO arguments: domainName requiresSSL"
            sys.exit()
        else:
            if (len(sys.argv) == 1):	
                print enableSSO("")
            elif(len(sys.argv) == 2 or (len(sys.argv) == 3 and sys.argv[2].lower() == "false")):
                print enableSSO(sys.argv[1], "false")
            else:
                print enableSSO(sys.argv[1], "true")
            print saveChange()
            print "Operation completed successfully"
            print ""
            print showSSO()
            sys.exit()
elif (sys.argv[0]=="disableSSO"):
	print ""
	print disableSSO()
	print saveChange()
	print "Operation completed successfully"
	print ""
        print showSSO()
	sys.exit()
elif (sys.argv[0]=="importLTPAKeys"):
	print ""
	if (len(sys.argv) != 3):
		print "importLTPAKeys arguments: keyFile, password"
	else:
	        print "Note: LTPA key file path needs to be absolute"
	        print "Trying to import LTPA key file [" + sys.argv[1] +"] with password -- " + sys.argv[2]
		print importLTPAKeys(sys.argv[1], sys.argv[2])
		print saveChange()
		print "Operation completed successfully"
		print ""
	sys.exit()
elif (sys.argv[0]=="exportLTPAKeys"):
	print ""
	if (len(sys.argv) != 3):
		print "exportLTPAKeys arguments: keyFile, password"
	else:
	        print "Note: LTPA key file path needs to be absolute"
	        print "Trying to export LTPA key file to [" + sys.argv[1] + "] with password -- " + sys.argv[2]
		print exportLTPAKeys(sys.argv[1], sys.argv[2])
		print "Operation completed successfully"
		print ""
	sys.exit()
else:
    print "Invalid input, exiting ...."
    sys.exit()